@@ -22,27 +22,35 @@
 
 #include <config-kiocore.h>
 
-#include <sys/types.h>
-#include <pwd.h>
-#include <grp.h>
-#include <sys/stat.h>
+#include <qplatformdefs.h>
 #if HAVE_POSIX_ACL
 #include <sys/acl.h>
 #include <acl/libacl.h>
 #endif
 #include <QHash>
 #include <QString>
+#include <QDataStream>
 
 #include <QList>
 #include <QPair>
 
+#include <memory>
+
+#include "kiocoredebug.h"
+
 class KACL::KACLPrivate
 {
 public:
-    KACLPrivate() : m_acl(0) {}
+    KACLPrivate()
+#if HAVE_POSIX_ACL
+        : m_acl(nullptr)
+#endif
+    {}
 #if HAVE_POSIX_ACL
     KACLPrivate(acl_t acl)
         : m_acl(acl) {}
+#endif
+#if HAVE_POSIX_ACL
     ~KACLPrivate()
     {
         if (m_acl) {
@@ -59,11 +67,9 @@ public:
     bool setNamedUserOrGroupPermissions(const QString &name, unsigned short permissions, acl_tag_t type);
 
     acl_t m_acl;
-#else
-    int m_acl;
-#endif
     mutable QHash<uid_t, QString> m_usercache;
     mutable QHash<gid_t, QString> m_groupcache;
+#endif
 };
 
 KACL::KACL(const QString &aclString)
@@ -137,7 +143,7 @@ bool KACL::isValid() const
 bool KACL::isExtended() const
 {
 #if HAVE_POSIX_ACL
-    return (acl_equiv_mode(d->m_acl, NULL) != 0);
+    return (acl_equiv_mode(d->m_acl, nullptr) != 0);
 #else
     return false;
 #endif
@@ -156,12 +162,12 @@ static acl_entry_t entryForTag(acl_t acl, acl_tag_t tag)
         }
         ret = acl_get_entry(acl, ACL_NEXT_ENTRY, &entry);
     }
-    return 0;
+    return nullptr;
 }
 
 static unsigned short entryToPermissions(acl_entry_t entry)
 {
-    if (entry == 0) {
+    if (entry == nullptr) {
         return 0;
     }
     acl_permset_t permset;
@@ -175,7 +181,7 @@ static unsigned short entryToPermissions(acl_entry_t entry)
 
 static void permissionsToEntry(acl_entry_t entry, unsigned short v)
 {
-    if (entry == 0) {
+    if (entry == nullptr) {
         return;
     }
     acl_permset_t permset;
@@ -199,7 +205,7 @@ static void permissionsToEntry(acl_entry_t entry, unsigned short v)
 static void printACL(acl_t acl, const QString &comment)
 {
     const char *txt = acl_to_text(acl);
-    qDebug() << comment << txt;
+    qCDebug(KIO_CORE) << comment << txt;
     acl_free(txt);
 }
 #endif
@@ -324,7 +330,7 @@ unsigned short KACL::maskPermissions(bool &exists) const
     exists = true;
 #if HAVE_POSIX_ACL
     acl_entry_t entry = entryForTag(d->m_acl, ACL_MASK);
-    if (entry == 0) {
+    if (entry == nullptr) {
         exists = false;
         return 0;
     }
@@ -338,7 +344,7 @@ unsigned short KACL::maskPermissions(bool &exists) const
 bool KACL::KACLPrivate::setMaskPermissions(unsigned short v)
 {
     acl_entry_t entry = entryForTag(m_acl, ACL_MASK);
-    if (entry == 0) {
+    if (entry == nullptr) {
         acl_create_entry(&m_acl, &entry);
         acl_set_tag_type(entry, ACL_MASK);
     }
@@ -357,6 +363,10 @@ bool KACL::setMaskPermissions(unsigned short v)
 #endif
 }
 
+#if HAVE_POSIX_ACL
+using unique_ptr_acl_free = std::unique_ptr<void, int(*)(void*)>;
+#endif
+
 /**************************
  * Deal with named users  *
  **************************/
@@ -364,14 +374,14 @@ unsigned short KACL::namedUserPermissions(const QString &name, bool *exists) con
 {
 #if HAVE_POSIX_ACL
     acl_entry_t entry;
-    uid_t id;
     *exists = false;
     int ret = acl_get_entry(d->m_acl, ACL_FIRST_ENTRY, &entry);
     while (ret == 1) {
         acl_tag_t currentTag;
         acl_get_tag_type(entry, &currentTag);
         if (currentTag ==  ACL_USER) {
-            id = *((uid_t *) acl_get_qualifier(entry));
+            const unique_ptr_acl_free idptr(acl_get_qualifier(entry), acl_free);
+            const uid_t id = *(static_cast<uid_t *>(idptr.get()));
             if (d->getUserName(id) == name) {
                 *exists = true;
                 return entryToPermissions(entry);
@@ -399,7 +409,8 @@ bool KACL::KACLPrivate::setNamedUserOrGroupPermissions(const QString &name, unsi
         acl_tag_t currentTag;
         acl_get_tag_type(entry, &currentTag);
         if (currentTag == type) {
-            int id = * (int *)acl_get_qualifier(entry);
+            const unique_ptr_acl_free idptr(acl_get_qualifier(entry), acl_free);
+            const int id = * (static_cast<int *>(idptr.get()));  // We assume that sizeof(uid_t) == sizeof(gid_t)
             const QString entryName = type == ACL_USER ? getUserName(id) : getGroupName(id);
             if (entryName == name) {
                 // found him, update
@@ -426,7 +437,7 @@ bool KACL::KACLPrivate::setNamedUserOrGroupPermissions(const QString &name, unsi
         // 23.1.1 of 1003.1e states that as soon as there is a named user or
         // named group entry, there needs to be a mask entry as well, so add
         // one, if the user hasn't explicitly set one.
-        if (entryForTag(newACL, ACL_MASK) == 0) {
+        if (entryForTag(newACL, ACL_MASK) == nullptr) {
             acl_calc_mask(&newACL);
         }
     }
@@ -458,13 +469,13 @@ ACLUserPermissionsList KACL::allUserPermissions() const
     ACLUserPermissionsList list;
 #if HAVE_POSIX_ACL
     acl_entry_t entry;
-    uid_t id;
     int ret = acl_get_entry(d->m_acl, ACL_FIRST_ENTRY, &entry);
     while (ret == 1) {
         acl_tag_t currentTag;
         acl_get_tag_type(entry, &currentTag);
         if (currentTag ==  ACL_USER) {
-            id = *((uid_t *) acl_get_qualifier(entry));
+            const unique_ptr_acl_free idptr(acl_get_qualifier(entry), acl_free);
+            const uid_t id = *(static_cast<uid_t *>(idptr.get()));
             QString name = d->getUserName(id);
             unsigned short permissions = entryToPermissions(entry);
             ACLUserPermissions pair = qMakePair(name, permissions);
@@ -525,7 +536,7 @@ bool KACL::KACLPrivate::setAllUsersOrGroups(const QList< QPair<QString, unsigned
         // 23.1.1 of 1003.1e states that as soon as there is a named user or
         // named group entry, there needs to be a mask entry as well, so add
         // one, if the user hasn't explicitly set one.
-        if (entryForTag(newACL, ACL_MASK) == 0) {
+        if (entryForTag(newACL, ACL_MASK) == nullptr) {
             acl_calc_mask(&newACL);
         }
     }
@@ -558,13 +569,13 @@ unsigned short KACL::namedGroupPermissions(const QString &name, bool *exists) co
     *exists = false;
 #if HAVE_POSIX_ACL
     acl_entry_t entry;
-    gid_t id;
     int ret = acl_get_entry(d->m_acl, ACL_FIRST_ENTRY, &entry);
     while (ret == 1) {
         acl_tag_t currentTag;
         acl_get_tag_type(entry, &currentTag);
         if (currentTag ==  ACL_GROUP) {
-            id = *((gid_t *) acl_get_qualifier(entry));
+            const unique_ptr_acl_free idptr(acl_get_qualifier(entry), acl_free);
+            const gid_t id = *(static_cast<gid_t *>(idptr.get()));
             if (d->getGroupName(id) == name) {
                 *exists = true;
                 return entryToPermissions(entry);
@@ -594,13 +605,13 @@ ACLGroupPermissionsList KACL::allGroupPermissions() const
     ACLGroupPermissionsList list;
 #if HAVE_POSIX_ACL
     acl_entry_t entry;
-    gid_t id;
     int ret = acl_get_entry(d->m_acl, ACL_FIRST_ENTRY, &entry);
     while (ret == 1) {
         acl_tag_t currentTag;
         acl_get_tag_type(entry, &currentTag);
         if (currentTag ==  ACL_GROUP) {
-            id = *((gid_t *) acl_get_qualifier(entry));
+            const unique_ptr_acl_free idptr(acl_get_qualifier(entry), acl_free);
+            const gid_t id = *(static_cast<gid_t *>(idptr.get()));
             QString name = d->getGroupName(id);
             unsigned short permissions = entryToPermissions(entry);
             ACLGroupPermissions pair = qMakePair(name, permissions);
